@@ -1,5 +1,5 @@
 /*
- *  $Id: dialog.h,v 1.139 2004/03/14 23:42:40 tom Exp $
+ *  $Id: dialog.h,v 1.145 2004/09/19 15:49:23 tom Exp $
  *
  *  dialog.h -- common declarations for all dialog modules
  *
@@ -36,7 +36,7 @@
 #include <signal.h>	/* fork() etc. */
 #include <math.h>	/* sqrt() */
 
-#if defined(HAVE_NCURSESW_NCURSES_H)
+#if defined(DLG_HAVE_NCURSESW_NCURSES_H)
 #include <ncursesw/ncurses.h>
 #elif defined(HAVE_NCURSES_NCURSES_H)
 #include <ncurses/ncurses.h>
@@ -59,7 +59,7 @@
 #undef buttons
 #endif
 
-#ifdef ENABLE_NLS
+#ifdef DLG_ENABLE_NLS
 #include <libintl.h>
 #include <langinfo.h>
 #define _(s) gettext(s)
@@ -76,8 +76,8 @@
 #define GCC_UNUSED /*nothing*/
 #endif
 
-#ifndef HAVE_WGET_WCH
-#undef USE_WIDE_CURSES
+#ifndef DLG_HAVE_WGET_WCH
+#undef DLG_USE_WIDE_CURSES
 #endif
 
 /*
@@ -94,7 +94,7 @@
 #define USE_SHADOW TRUE
 #define USE_COLORS TRUE
 
-#ifdef HAVE_COLOR
+#ifdef DLG_HAVE_COLOR
 #define SCOLS	(COLS - (dialog_state.use_shadow ? 2 : 0))
 #define SLINES	(LINES - (dialog_state.use_shadow ? 1 : 0))
 #else
@@ -177,23 +177,27 @@
 #endif
 
 /* these definitions may work for antique versions of curses */
-#ifndef HAVE_GETBEGYX
+#ifndef DLG_HAVE_GETBEGYX
 #undef  getbegyx
 #define getbegyx(win,y,x)	(y = (win)?(win)->_begy:ERR, x = (win)?(win)->_begx:ERR)
 #endif
 
-#ifndef HAVE_GETMAXYX
+#ifndef DLG_HAVE_GETMAXYX
 #undef  getmaxyx
 #define getmaxyx(win,y,x)	(y = (win)?(win)->_maxy:ERR, x = (win)?(win)->_maxx:ERR)
 #endif
 
-#ifndef HAVE_GETPARYX
+#ifndef DLG_HAVE_GETPARYX
 #undef  getparyx
 #define getparyx(win,y,x)	(y = (win)?(win)->_pary:ERR, x = (win)?(win)->_parx:ERR)
 #endif
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 /* these definitions may be needed for bleeding-edge curses implementations */
-#if !(defined(HAVE_GETBEGX) && defined(HAVE_GETBEGY))
+#if !(defined(DLG_HAVE_GETBEGX) && defined(DLG_HAVE_GETBEGY))
 #undef getbegx
 #undef getbegy
 #define getbegx(win) dlg_getbegx(win)
@@ -202,7 +206,7 @@ extern int dlg_getbegx(WINDOW *);
 extern int dlg_getbegy(WINDOW *);
 #endif
 
-#if !(defined(HAVE_GETCURX) && defined(HAVE_GETCURY))
+#if !(defined(DLG_HAVE_GETCURX) && defined(DLG_HAVE_GETCURY))
 #undef getcurx
 #undef getcury
 #define getcurx(win) dlg_getcurx(win)
@@ -211,7 +215,7 @@ extern int dlg_getcurx(WINDOW *);
 extern int dlg_getcury(WINDOW *);
 #endif
 
-#if !(defined(HAVE_GETMAXX) && defined(HAVE_GETMAXY))
+#if !(defined(DLG_HAVE_GETMAXX) && defined(DLG_HAVE_GETMAXY))
 #undef getmaxx
 #undef getmaxy
 #define getmaxx(win) dlg_getmaxx(win)
@@ -220,7 +224,7 @@ extern int dlg_getmaxx(WINDOW *);
 extern int dlg_getmaxy(WINDOW *);
 #endif
 
-#if !(defined(HAVE_GETPARX) && defined(HAVE_GETPARY))
+#if !(defined(DLG_HAVE_GETPARX) && defined(DLG_HAVE_GETPARY))
 #undef getparx
 #undef getpary
 #define getparx(win) dlg_getparx(win)
@@ -352,6 +356,7 @@ typedef struct {
     FILE *screen_output;	/* newterm(), etc. */
     bool screen_initialized;
     bool use_colors;		/* use colors by default? */
+    bool use_scrollbar;		/* RESERVED */
     bool use_shadow;		/* shadow dialog boxes by default? */
     bool visit_items;		/* option "--visit-items" */
     char *separate_str;		/* option "--separate-widget string" */
@@ -385,6 +390,7 @@ typedef struct {
     bool nocollapse;		/* option "--no-collapse" */
     bool print_siz;		/* option "--print-size" */
     bool separate_output;	/* option "--separate-output" */
+    bool single_quoted;		/* option "--single-quoted" */
     bool size_err;		/* option "--size-err" */
     bool tab_correct;		/* option "--tab-correct" */
     bool trim_whitespace;	/* option "--trim" */
@@ -402,6 +408,7 @@ typedef struct {
     int begin_x;		/* option "--begin y x" (second value) */
     int begin_y;		/* option "--begin y x" (first value) */
     int max_input;		/* option "--max-input size" */
+    int scale_factor;		/* RESERVED */
     int sleep_secs;		/* option "--sleep secs" */
     int timeout_secs;		/* option "--timeout secs" */
     unsigned input_length;	/* nonzero if input_result is allocated */
@@ -414,7 +421,7 @@ typedef struct {
 
 extern DIALOG_VARS dialog_vars;
 
-#ifndef HAVE_TYPE_CHTYPE
+#ifndef DLG_HAVE_TYPE_CHTYPE
 #define chtype long
 #endif
 
@@ -427,12 +434,12 @@ extern DIALOG_VARS dialog_vars;
  */
 typedef struct {
     chtype atr;
-#ifdef HAVE_COLOR
+#ifdef DLG_HAVE_COLOR
     int fg;
     int bg;
     int hilite;
 #endif
-#ifdef HAVE_RC_FILE
+#ifdef DLG_HAVE_RC_FILE
     char *name;
     char *comment;
 #endif
@@ -461,6 +468,7 @@ extern int dialog_yesno(const char *title, const char *cprompt, int height, int
 
 /* arrows.c */
 extern void dlg_draw_arrows(WINDOW *dialog, int top_arrow, int bottom_arrow, int x, int top, int bottom);
+extern void dlg_draw_arrows2(WINDOW *dialog, int top_arrow, int bottom_arrow, int x, int top, int bottom, chtype attr, chtype borderattr);
 
 /* buttons.c */
 extern const char ** dlg_exit_label(void);
@@ -491,7 +499,7 @@ extern int dlg_limit_columns(const char *string, int limit, int offset);
 extern void dlg_show_string(WINDOW *win, const char *string, int offset, chtype attr, int y_base, int x_base, int x_last, bool hidden, bool force);
 
 /* rc.c */
-#ifdef HAVE_RC_FILE
+#ifdef DLG_HAVE_RC_FILE
 extern int dlg_parse_rc(void);
 extern void dlg_create_rc(const char *filename);
 #endif
@@ -546,13 +554,14 @@ __attribute__((format(printf,1,2)))
 #endif
 ;
 
-#ifdef HAVE_COLOR
+#ifdef DLG_HAVE_COLOR
+extern chtype dlg_color_pair(int foreground, int background);
 extern int dlg_color_count(void);
 extern void dlg_color_setup(void);
 extern void dlg_draw_shadow(WINDOW * win, int height, int width, int y, int x);
 #endif
 
-#ifdef HAVE_STRCASECMP
+#ifdef DLG_HAVE_STRCASECMP
 #define dlg_strcmp(a,b) strcasecmp(a,b)
 #else
 extern int dlg_strcmp(const char *a, const char *b);
@@ -616,4 +625,18 @@ extern int dlg_mouse_wgetch (WINDOW *, int *);
 #define FLAG_CHECK 1
 #define FLAG_RADIO 0
 
+/*
+ * This is used only for debugging (FIXME: should have a separate header).
+ */
+#ifdef NO_LEAKS
+extern void _dlg_inputstr_leaks(void);
+#ifdef NCURSES_VERSION
+extern void _nc_free_and_exit(int);	/* nc_alloc.h normally not installed */
+#endif
+#endif
+
+#ifdef __cplusplus
+}
+#endif
+
 #endif /* DIALOG_H_included */
