@@ -42,9 +42,9 @@ $^V eq v5.8.4
 #
 ## Package name      : perl5
 ## Source directory  : .
-## Configuration time: Sat Jun 26 02:18:47 UTC 2004
+## Configuration time: Tue Nov  2 18:35:29 CET 2004
 ## Configured by     : Debian Project
-## Target system     : gnu gnu 0.3 gnumach-1.3hurd-0.3 i386-at386 gnu 
+## Target system     : gnu debian 0.3 gnu-mach 1.3hurd-0.3 i386-at386 gnu 
 #
 ## Configure command line arguments.
 #PERL_PATCHLEVEL=
@@ -94,8 +94,8 @@ our $Config_SH : unique = <<'!END!';
 archlibexp='/usr/lib/perl/5.8'
 archname='i386-gnu-thread-multi'
 cc='cc'
-ccflags='-DDEBIAN -fno-strict-aliasing -I/usr/local/include'
-cppflags='-DDEBIAN -fno-strict-aliasing -I/usr/local/include'
+ccflags='-D_GNU_SOURCE -fno-strict-aliasing -I/usr/local/include'
+cppflags='-D_GNU_SOURCE -fno-strict-aliasing -I/usr/local/include'
 dlsrc='dl_dlopen.xs'
 dynamic_ext='B ByteLoader Cwd DB_File Data/Dumper Devel/DProf Devel/PPPort Devel/Peek Digest/MD5 Encode Fcntl File/Glob Filter/Util/Call GDBM_File I18N/Langinfo IO List/Util MIME/Base64 NDBM_File ODBM_File Opcode POSIX PerlIO/encoding PerlIO/scalar PerlIO/via SDBM_File Socket Storable Sys/Hostname Sys/Syslog Time/HiRes Unicode/Normalize XS/APItest XS/Typemap attrs re threads threads/shared'
 installarchlib='/usr/lib/perl/5.8'
@@ -164,11 +164,11 @@ cccdlflags='-fPIC'
 ccdlflags='-Wl,-E'
 ccflags_uselargefiles=''
 ccname='gcc'
-ccsymbols='__GNUC_MINOR__=3 __GNUC_PATCHLEVEL__=3 __GNUC__=3'
+ccsymbols='__GNUC_MINOR__=3 __GNUC_PATCHLEVEL__=5 __GNUC__=3'
 ccversion=''
 cf_by='Debian Project'
 cf_email='perl@packages.debian.org'
-cf_time='Sat Jun 26 02:18:47 UTC 2004'
+cf_time='Tue Nov  2 18:35:29 CET 2004'
 charsize='1'
 chgrp=''
 chmod='chmod'
@@ -218,7 +218,7 @@ cpplast='-'
 cppminus='-'
 cpprun='cc -E'
 cppstdin='cc -E'
-cppsymbols='__ELF__=1 __GLIBC__=2 __GLIBC_MINOR__=3 __GNU__=1 __GNUC__=3 __GNUC_MINOR__=3 __GNU_LIBRARY__=6 MACH=1 __MACH=1 __MACH__=1 _POSIX_C_SOURCE=199506 _POSIX_SOURCE=1 __STDC__=1 __USE_BSD=1 __USE_MISC=1 __USE_POSIX=1 __USE_POSIX199309=1 __USE_POSIX199506=1 __USE_POSIX2=1 __USE_SVID=1 i386=1 __i386=1 __i386__=1 __i586=1 __i586__=1 unix=1 __unix=1 __unix__=1'
+cppsymbols='__ELF__=1 __GLIBC__=2 __GLIBC_MINOR__=3 __GNU__=1 __GNUC__=3 __GNUC_MINOR__=3 __GNU_LIBRARY__=6 _GNU_SOURCE=1 _LARGEFILE64_SOURCE=1 _LARGEFILE_SOURCE=1 MACH=1 __MACH=1 __MACH__=1 _POSIX_C_SOURCE=199506 _POSIX_SOURCE=1 __STDC__=1 __USE_BSD=1 __USE_GNU=1 __USE_LARGEFILE=1 __USE_LARGEFILE64=1 __USE_MISC=1 __USE_POSIX=1 __USE_POSIX199309=1 __USE_POSIX199506=1 __USE_POSIX2=1 __USE_SVID=1 __USE_UNIX98=1 __USE_XOPEN=1 __USE_XOPEN_EXTENDED=1 _XOPEN_SOURCE=600 _XOPEN_SOURCE_EXTENDED=1 i386=1 __i386=1 __i386__=1 __i586=1 __i586__=1 unix=1 __unix=1 __unix__=1'
 crypt_r_proto='REENTRANT_PROTO_B_CCS'
 cryptlib=''
 csh='csh'
@@ -306,7 +306,7 @@ d_fcntl='define'
 d_fcntl_can_lock='define'
 d_fd_macros='define'
 d_fd_set='define'
-d_fds_bits='undef'
+d_fds_bits='define'
 d_fgetpos='define'
 d_finite='define'
 d_finitel='define'
@@ -447,7 +447,7 @@ d_mymalloc='define'
 d_nice='define'
 d_nl_langinfo='define'
 d_nv_preserves_uv='define'
-d_off64_t='undef'
+d_off64_t='define'
 d_old_pthread_create_joinable='undef'
 d_oldpthreads='undef'
 d_oldsock='undef'
@@ -542,7 +542,7 @@ d_sigaction='define'
 d_sigprocmask='define'
 d_sigsetjmp='define'
 d_sockatmark='define'
-d_sockatmarkproto='undef'
+d_sockatmarkproto='define'
 d_socket='define'
 d_socklen_t='define'
 d_sockpair='define'
@@ -550,8 +550,8 @@ d_socks5_init='undef'
 d_sqrtl='define'
 d_srand48_r='define'
 d_srandom_r='define'
-d_sresgproto='undef'
-d_sresuproto='undef'
+d_sresgproto='define'
+d_sresuproto='define'
 d_statblks='define'
 d_statfs_f_flags='undef'
 d_statfs_s='define'
@@ -666,7 +666,7 @@ full_csh='csh'
 full_sed='/usr/bin/sed'
 gccansipedantic=''
 gccosandvers=''
-gccversion='3.3.3 (Debian 20040321)'
+gccversion='3.3.5 (Debian 1:3.3.5-2)'
 getgrent_r_proto='REENTRANT_PROTO_I_SBWR'
 getgrgid_r_proto='REENTRANT_PROTO_I_TSBWR'
 getgrnam_r_proto='REENTRANT_PROTO_I_CSBWR'
@@ -702,7 +702,7 @@ gzip='gzip'
 h_fcntl='false'
 h_sysfile='true'
 hint='recommended'
-hostcat=''
+hostcat='cat /etc/hosts'
 html1dir=' '
 html1direxp=''
 html3dir=' '
@@ -890,7 +890,7 @@ mv=''
 myarchname='i386-AT386-gnu'
 mydomain=''
 myhostname='localhost'
-myuname='gnu gnu 0.3 gnumach-1.3hurd-0.3 i386-at386 gnu '
+myuname='gnu debian 0.3 gnu-mach 1.3hurd-0.3 i386-at386 gnu '
 n='-n'
 need_va_copy='undef'
 netdb_hlen_type='size_t'
@@ -1295,8 +1295,8 @@ tie %Config, 'Config', {
     'archlibexp' => '/usr/lib/perl/5.8',
     'archname' => 'i386-gnu-thread-multi',
     'cc' => 'cc',
-    'ccflags' => '-DDEBIAN -fno-strict-aliasing -I/usr/local/include',
-    'cppflags' => '-DDEBIAN -fno-strict-aliasing -I/usr/local/include',
+    'ccflags' => '-D_GNU_SOURCE -fno-strict-aliasing -I/usr/local/include',
+    'cppflags' => '-D_GNU_SOURCE -fno-strict-aliasing -I/usr/local/include',
     'dlsrc' => 'dl_dlopen.xs',
     'dynamic_ext' => 'B ByteLoader Cwd DB_File Data/Dumper Devel/DProf Devel/PPPort Devel/Peek Digest/MD5 Encode Fcntl File/Glob Filter/Util/Call GDBM_File I18N/Langinfo IO List/Util MIME/Base64 NDBM_File ODBM_File Opcode POSIX PerlIO/encoding PerlIO/scalar PerlIO/via SDBM_File Socket Storable Sys/Hostname Sys/Syslog Time/HiRes Unicode/Normalize XS/APItest XS/Typemap attrs re threads threads/shared',
     'installarchlib' => '/usr/lib/perl/5.8',
